TEAM_DETAILS_URI = "https://stats.nba.com/stats/teamdetails?"
COMMON_TEAM_ROSTER_URI = "https://stats.nba.com/stats/commonteamroster?"
FRANCHISE_LEADER_URI = "https://stats.nba.com/stats/franchiseleaders?"

TEAMS = {
    "Celtics": 1610612738,
    "Spurs": 1610612759
}